#ifndef exposemanifold 
#define exposemanifold

#include "scorematchingad_forward.h"
#include "manifoldtransforms/manifolds.hpp"
#include "manifoldtransforms/transforms.hpp"
#include <Rcpp.h>


#endif

